@@ -17,6 +17,12 @@ our @EXPORT = qw(
     recursive_child_files
 );
 
+use if "$]" >= 5.022, experimental => 're_strict';
+no if "$]" >= 5.031009, feature => 'indirect';
+no if "$]" >= 5.033001, feature => 'multidimensional';
+no if "$]" >= 5.033006, feature => 'bareword_filehandles';
+no if "$]" >= 5.041009, feature => 'smartmatch';
+no feature 'switch';
 use Test::More 0.96;
 use Test::Deep;
 use List::Util 1.45 'uniq';
